@@ -40,6 +40,8 @@
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/grad.png grad.png )
 ( cd opt/kde/share/doc/HTML/uk/common ; rm -rf kde-web.css )
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
+( cd opt/kde/share/doc/HTML/uk/common ; rm -rf kde_logo_bg.png )
+( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
 ( cd opt/kde/share/doc/HTML/uk/common ; rm -rf lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/uk/common ; rm -rf doxygen.css )
@@ -54,12 +56,16 @@
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/uk/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/uk/common ; rm -rf appheader.html )
+( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/uk/common ; rm -rf doctop1.png )
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
 ( cd opt/kde/share/doc/HTML/uk/common ; rm -rf doctop2.png )
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
 ( cd opt/kde/share/doc/HTML/uk/common ; rm -rf shadow.png )
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/shadow.png shadow.png )
+( cd opt/kde/share/doc/HTML/uk/common ; rm -rf kde_logo.png )
+( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/uk/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
 ( cd opt/kde/share/doc/HTML/uk/common ; rm -rf fdl-license.html )
@@ -90,7 +96,5 @@
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
 ( cd opt/kde/share/doc/HTML/uk/common ; rm -rf artistic-license.html )
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
-( cd opt/kde/share/doc/HTML/uk/kspell ; rm -rf common )
-( cd opt/kde/share/doc/HTML/uk/kspell ; ln -sf /opt/kde/share/doc/HTML/uk/common common )
 ( cd opt/kde/share/doc/HTML/uk/kinfocenter/protocols ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/uk/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/uk/common common )
